@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: lrucache
 version: 1.2.0.0
-id: lrucache-1.2.0.0-3a28e4fefc3e5f1a602d3f3824abd887
-key: lruca_Js9kK0H2W5k8kupnq32m6X
+id: lrucache-1.2.0.0-0e1bc1011b1da1204dc9533222aae2b2
+key: lruca_J7Z7OMaVTsu6o3E1fwi2zS
 license: BSD3
 copyright: Carl Howells, 2010-2015
 maintainer: chowells79@gmail.com
@@ -26,11 +26,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/lrucache-1.2.0.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/lrucache-1.2.0.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/lrucache-1.2.0.0
-hs-libraries: HSlrucache-1.2.0.0-Js9kK0H2W5k8kupnq32m6X
+hs-libraries: HSlrucache-1.2.0.0-J7Z7OMaVTsu6o3E1fwi2zS
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    contravariant-1.4-db788d767efca0b89f051d890d0c132d
+    contravariant-1.4-40742dd1a022cbf40c8c77a36d4f0610
 haddock-interfaces: /usr/share/doc/haskell-lrucache/html/lrucache.haddock
 haddock-html: /usr/share/doc/haskell-lrucache/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
